@@ -301,7 +301,7 @@ class Microservice(core.Construct):
 
         return tg
 
-    def create_load_balancer(self, scope, id, app_name, environment, environments_parameters, security_group=None, internet_facing=False, load_balancer_name=None, use_cdn=False):
+    def create_load_balancer(self, scope, id, app_name, environment, environments_parameters, security_group=None, internet_facing=False, load_balancer_name=None, use_cdn=False, main_component_name=None):
         """Create a Load Balancer resource
         
         Args:
@@ -391,7 +391,7 @@ class Microservice(core.Construct):
         if internet_facing is False:
             aws_account = environments_parameters["accounts"][environment.lower()]
             app_proxy_security_group = _ec2.SecurityGroup.from_security_group_id(
-                self, "upstream_security_group", aws_account["app_proxy_security_group"], mutable=False
+                self, "upstream_security_group_app_proxy_"+main_component_name, aws_account["app_proxy_security_group"], mutable=False
             )
             alb.add_security_group(app_proxy_security_group)
         
@@ -745,7 +745,7 @@ class Microservice(core.Construct):
                 description="Everyone",
             )
 
-        if is_public_and_has_upstream:
+        if has_upstream:
             self.alb_security_group.add_ingress_rule(
                 peer=upstream_security_group_as_peer,
                 connection=self._tcp_connection_traffic_port,
@@ -791,7 +791,8 @@ class Microservice(core.Construct):
             self.alb_security_group, 
             internet_facing=is_public, 
             load_balancer_name='-'.join([app_name, main_component_name, 'alb']), 
-            use_cdn=use_cdn
+            use_cdn=use_cdn,
+            main_component_name=main_component_name
         )
 
         # Listeners
